@@ -67,9 +67,9 @@ impl<T: Float + AddAssign + std::fmt::Debug> Scalar for T {}
 
 /// A point in the space to be searched
 pub trait Point<T: Scalar>: Default {
-    /// Sets the value for the `i`-the component, `i` must be within `0..DIM`.
+    /// Sets the value for the `i`-th component, `i` must be within `0..DIM`.
     fn set(&mut self, i: u32, value: NotNan<T>);
-    /// Gets the value for the `i`-the component, `i` must be within `0..DIM`.
+    /// Gets the value for the `i`-th component, `i` must be within `0..DIM`.
     fn get(&self, i: u32) -> NotNan<T>;
     /// The number of dimension of the space this point lies in.
     const DIM: u32;
@@ -83,7 +83,7 @@ pub trait Point<T: Scalar>: Default {
 
 /// Helper function to compute the square distance between two points given as slice
 #[inline]
-fn slice_dist2<T: Scalar, P: Point<T>>(lhs: &[NotNan<T>], rhs: &[NotNan<T>]) -> NotNan<T> {
+fn point_slice_dist2<T: Scalar, P: Point<T>>(lhs: &[NotNan<T>], rhs: &[NotNan<T>]) -> NotNan<T> {
     let mut dist2 = NotNan::<T>::zero();
     for index in 0..P::DIM {
         let index = index as usize;
@@ -97,6 +97,7 @@ fn slice_dist2<T: Scalar, P: Point<T>>(lhs: &[NotNan<T>], rhs: &[NotNan<T>]) ->
 pub type Index = u32;
 
 /// A neighbour resulting from the search
+#[derive(Debug)]
 pub struct Neighbour<T: Scalar, P: Point<T>> {
     /// the point itself
     pub point: P,
@@ -189,6 +190,7 @@ impl<T: Scalar, P: Point<T>> KDTree<T, P> {
 
     /// Finds the `k` nearest neighbour of `query`, using reasonable default parameters.
     ///
+    /// If there are less than `k` points in the point cloud, the returned vector will be smaller than `k`.
     /// The default parameters are:
     /// Exact search, no max. radius, allowing self matching, sorting results, and not collecting statistics.
     /// If `k` <= 16, a linear vector is used to keep track of candidates, otherwise a binary heap is used.
@@ -214,6 +216,8 @@ impl<T: Scalar, P: Point<T>> KDTree<T, P> {
 
     /// Finds the `k` nearest neighbour of `query`, with user-provided parameters.
     ///
+    /// If there are less than `k` points in the point cloud or in the ball around `query`
+    /// defined by `parameters.max_radius`, the returned vector will be smaller than `k`.
     /// The parameters are:
     /// * `candidate_container` which container to use to collect candidates,
     /// * `parameters` the advanced search parameters,
@@ -371,7 +375,7 @@ impl<T: Scalar, P: Point<T>> KDTree<T, P> {
                 for bucket_index in bucket_start_index..bucket_end_index {
                     let point_index = (bucket_index * P::DIM) as usize;
                     let point = &self.points[point_index..point_index + (P::DIM as usize)];
-                    let dist2 = slice_dist2::<T, P>(query, point);
+                    let dist2 = point_slice_dist2::<T, P>(query, point);
                     let epsilon = NotNan::new(T::epsilon()).unwrap();
                     let InternalParameters {
                         max_radius2,
@@ -708,4 +712,32 @@ mod tests {
             }
         }
     }
+
+    #[test]
+    fn small_clouds_can_lead_to_neighbours() {
+        let cloud = vec![P2::new(0.0, 0.0), P2::new(1.0, 0.0)];
+        let tree = KDTree::new(&cloud);
+        let query = P2::new(0.5, 0.0);
+        for _ in [CandidateContainer::Linear, CandidateContainer::BinaryHeap] {
+            let nns = tree.knn(3, &query);
+            assert_eq!(nns.len(), 2);
+        }
+    }
+
+    #[test]
+    fn max_radius_can_lead_to_neighbours() {
+        let cloud = vec![P2::new(0.0, 0.0), P2::new(1.0, 0.0)];
+        let tree = KDTree::new(&cloud);
+        let query = P2::new(0.1, 0.0);
+        let parameters = Parameters {
+            epsilon: 0.0,
+            max_radius: 0.5,
+            allow_self_match: false,
+            sort_results: false,
+        };
+        for container in [CandidateContainer::Linear, CandidateContainer::BinaryHeap] {
+            let nns = tree.knn_advanced(2, &query, container, &parameters, None);
+            assert_eq!(nns.len(), 1);
+        }
+    }
 }
